@@ -483,7 +483,7 @@ class ShadowPlot:
         def __init__(self, x_scale_factor = 1.0, y_scale_factor = 1.0):
             super(ShadowPlot.DetailedHistoWidget, self).__init__()
 
-            self.plot_canvas = gui.plotWindow(roi=False, control=False, position=True, logScale=True)
+            self.plot_canvas = gui.plotWindow(roi=False, control=False, position=True, logScale=True, fit=True)
             self.plot_canvas.setDefaultPlotLines(True)
             self.plot_canvas.setActiveCurveColor(color='blue')
             self.plot_canvas.setMinimumWidth(590*x_scale_factor)
